/*************************************************************
** filename:    game_freqcs.g
** description: construct confidence set from output of
**              game_freqobj.g
*************************************************************/

new;
closeall;
/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
_verbose = 1;       /** 1 for verbose **/

#include game_spec.g;
#include pathspec.g;
#include game_proc.src;

/********************************************************
* Configuration
********************************************************/

freqindx = 1;
covprob  = 0.6;
critval_ = cdfchii(covprob,3);

/********************************************************
**  Load Output Matrices from Obj Fcn Evaluation
********************************************************/

lpath      = resupath $+ "\\freq" $+ ftos(freqindx,"%*.*lf",1,0);
block_size = 10;

linput       = lpath $+ "\\Qthvec"  ;
open fhinput = ^linput for read;
Qth_vec      = readr( fhinput, 1); 
eofloop      = 0;
do until eofloop; 
   Qth_vec = Qth_vec | readr( fhinput, block_size );
   eofloop = eof(fhinput);
endo;
closeall fhinput;

linput       = lpath $+ "\\Qthmat"  ;
open fhinput = ^linput for read;
Qth_mat      = readr( fhinput, 1); 
eofloop      = 0;
do until eofloop; 
   Qth_mat = Qth_mat | readr( fhinput, block_size );
   eofloop = eof(fhinput);
endo;
closeall fhinput;

linput       = lpath $+ "\\IDS12vec"  ;
open fhinput = ^linput for read;
IDS12_vec      = readr( fhinput, 1); 
eofloop      = 0;
do until eofloop; 
   IDS12_vec = IDS12_vec | readr( fhinput, block_size );
   eofloop = eof(fhinput);
endo;
closeall fhinput;

linput       = lpath $+ "\\IDS12mat"  ;
open fhinput = ^linput for read;
IDS12_mat      = readr( fhinput, 1); 
eofloop      = 0;
do until eofloop; 
   IDS12_mat = IDS12_mat | readr( fhinput, block_size );
   eofloop = eof(fhinput);
endo;
closeall fhinput;

/********************************************************
**  Construct 1 dimensional confidence sets
**  via projection method
*********************************************************/

/* Compute points in joint confidence set */
Qth_veccs = delif(Qth_vec, Qth_vec[.,1] .ge critval_);

/* Compute points in joint identified set */
IDS12_veccs = delif(IDS12_vec, IDS12_vec[.,1] .== 0);

/* Projections */
th1_ci = minc(Qth_veccs[.,2])   ~ maxc(Qth_veccs[.,2]);
th1_id = minc(IDS12_veccs[.,2]) ~ maxc(IDS12_veccs[.,2]);

th2_ci = minc(Qth_veccs[.,3])   ~ maxc(Qth_veccs[.,3]);
th2_id = minc(IDS12_veccs[.,3]) ~ maxc(IDS12_veccs[.,3]);

"";
"Theta 1: ";
"Identified Set:      " th1_id;
"Confidence Interval: " th1_ci;
"";
"Theta 2: "; 
"Identified Set:     "  th2_id;
"Confidence Interval:"  th2_ci;

/********************************************************
**  Graphical Representation 
**  of 2 dimensional confidence sets
*********************************************************/

/* extract / remove grid
*/
th1_n    = cols(IDS12_mat)-1;
th2_n    = rows(IDS12_mat)-1;
th1_grid = IDS12_mat[th2_n+1,1:th1_n]';
th2_grid = IDS12_mat[1:th2_n,th1_n+1];

/* Identified Set
*/
IDS12nogrid_mat = IDS12_mat[1:th2_n,1:th1_n];

IDS12_matsel = ( sumc(IDS12nogrid_mat) .== 0 ); 
IDS12tr_mat  = ( delif(IDS12nogrid_mat',IDS12_matsel) )';
IDS12th1_grid   = ( delif(th1_grid,IDS12_matsel) );

IDS12_mat_temp = seqa(1,1,th2_n) .* IDS12tr_mat;
IDS12_ub = th2_grid[maxindc(IDS12_mat_temp[1:th2_n,.])'];

IDS12_mat_temp = seqa(th2_n,-1,th2_n) .* IDS12tr_mat;
IDS12_lb = th2_grid[maxindc(IDS12_mat_temp[1:th2_n,.])'];

/* close open ends */
if IDS12_ub[1] ne IDS12_lb[1];
   IDS12th1_grid = (IDS12th1_grid[1] - (IDS12th1_grid[2]-IDS12th1_grid[1])/100) |
                 IDS12th1_grid;
   IDS12_diff = (IDS12_ub[1]-IDS12_lb[1])/2;
   IDS12_ub   = (IDS12_lb[1]+IDS12_diff) | IDS12_ub;
   IDS12_lb   = (IDS12_lb[1]+IDS12_diff) | IDS12_lb;
endif;

IDS12th1_n = rows(IDS12th1_grid);

if IDS12_ub[IDS12th1_n] ne IDS12_lb[IDS12th1_n];
   IDS12th1_grid = IDS12th1_grid |
                (IDS12th1_grid[IDS12th1_n] + (IDS12th1_grid[IDS12th1_n]-IDS12th1_grid[IDS12th1_n-1])/100);
   IDS12_diff = (IDS12_ub[IDS12th1_n]-IDS12_lb[IDS12th1_n])/2;
   IDS12_ub   = IDS12_ub | (IDS12_lb[IDS12th1_n]+IDS12_diff);
   IDS12_lb   = IDS12_lb | (IDS12_lb[IDS12th1_n]+IDS12_diff);
endif;


/* Freq Confidence Set
*/
Qthnogrid_mat   = Qth_mat[1:th2_n,1:th1_n];
Qthnogrid_mat   = Qthnogrid_mat .le critval_;

Qth_matsel = ( sumc(Qthnogrid_mat) .== 0 ); 
Qthtr_mat  = ( delif(Qthnogrid_mat',Qth_matsel) )';
Qthth1_grid   = ( delif(th1_grid,Qth_matsel) );

Qth_mat_temp = seqa(1,1,th2_n) .* Qthtr_mat;
Qth_ub = th2_grid[maxindc(Qth_mat_temp[1:th2_n,.])'];

Qth_mat_temp = seqa(th2_n,-1,th2_n) .* Qthtr_mat;
Qth_lb = th2_grid[maxindc(Qth_mat_temp[1:th2_n,.])'];

/* close open ends */
if Qth_ub[1] ne Qth_lb[1];
   Qthth1_grid = (Qthth1_grid[1] - (Qthth1_grid[2]-Qthth1_grid[1])/100) |
                 Qthth1_grid;
   Qth_diff = (Qth_ub[1]-Qth_lb[1])/2;
   Qth_ub   = (Qth_lb[1]+Qth_diff) | Qth_ub;
   Qth_lb   = (Qth_lb[1]+Qth_diff) | Qth_lb;
endif;

Qthth1_n = rows(Qthth1_grid);

if Qth_ub[Qthth1_n] ne Qth_lb[Qthth1_n];
   Qthth1_grid = Qthth1_grid |
                (Qthth1_grid[Qthth1_n] + (Qthth1_grid[Qthth1_n]-Qthth1_grid[Qthth1_n-1])/100);
   Qth_diff = (Qth_ub[Qthth1_n]-Qth_lb[Qthth1_n])/2;
   Qth_ub   = Qth_ub | (Qth_lb[Qthth1_n]+Qth_diff);
   Qth_lb   = Qth_lb | (Qth_lb[Qthth1_n]+Qth_diff);
endif;


/********************************************************
* Initialize Output files
********************************************************/

opath    = resupath $+ "\\freq" $+ ftos(freqindx,"%*.*lf",1,0);
ofreqcs  = opath  $+ "\\FreqCS2dim" $+ ftos(100*covprob,"%*.*lf",2,0);
oids     = opath  $+ "\\IDS2dim";

create fhfreqcs = ^ofreqcs with FREQCS, rows(Qthth1_grid), 8;
wr = writer(fhfreqcs,(Qthth1_grid~Qth_ub~Qth_lb)');
closeall fhfreqcs;

create fhids = ^oids with IDS, rows(IDS12th1_grid), 8;
wr = writer(fhids,(IDS12th1_grid~IDS12_ub~IDS12_lb)');
closeall fhids;


/********************************************************
* Plot some results
********************************************************/

graphset;
begwind;
margin(0.2,0.2,0.2,0.2); 

window(1,1,0);
fonts("microb");
_pcolor = {2 2};
_pltype = {6 6};
_plwidth = 8;
_psymsiz = 3;
_plctrl = -1;
_plctrl=0;

xtics(0,2,0.5,1);
ytics(0,2,0.5,1);
xy(IDS12th1_grid,IDS12_ub~IDS12_lb);

_pcolor = {4 4};
_pltype = {2 2};

xy(Qthth1_grid,Qth_ub~Qth_lb);

endwind;

end;
