/* filename:    game_prior.g
** description: The program generates draws from the prior of the 
**              entry game model
*/

new;

/** set seed **/
/** random number generator used in optimization procedure **/
/* rndseed 1234; */

/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls; 
outwidth 256;

format /mat /on /mb1 /ros 16,8;

#include game_spec.g;
#include game_proc.src;
#include pathspec.g;

block_n    = 10;
block_size = 10000;
mhrun      = "0";   /* NOTE: we use mhrun = 0 to denote prior */
opath      = parapath $+ "\\mhrun" $+ mhrun;
chkdir     = chk_dir(opath);

/********************************************************
*  Import prior specification
********************************************************/
priorfile = prioname $+ ".txt";
load path = ^priopath prior[] = ^priorfile;
prior = reshape(prior,rows(prior)/5,5);

pshape   = prior[.,1];
pmean    = prior[.,2];
pstdd    = prior[.,3];
pmask    = prior[.,4];
  /* make sure that del2 is fixed if msel[1]=2 */
  if msel[1] == 2; pmask[4]=1; endif;
pfix     = prior[.,5];
pmaskinv = 1-pmask;
pshape   = pshape.*pmaskinv;


/******************************************************** 
**  Initialize Output files
*/

opath   = parapath $+ "\\mhrun" $+ mhrun;
chkdir  = chk_dir(opath);

opara  = opath $+ "\\pa";
create fhpara = ^opara with para, ndgp_+nphi_+nadd_, 8;

/* Loop to generate parameter draws
*/
block_it = 1;
para_acpt = 0;

do until block_it > block_n;

   /* Generate theta and alpha draws
   */

   parasim = zeros(block_size,ndgp_);

   i = 1; 
   do until i > ndgp_;
   
      if pshape[i] == 1; /* BETA Prior */
         a = (1-pmean[i])*pmean[i]^2/pstdd[i]^2 - pmean[i];
         b = a*(1/pmean[i] - 1);
         parasim[.,i] = rndbeta(block_size,1,a,b);
      
      elseif pshape[i] == 2; /* GAMMA PRIOR */
         b = pstdd[i]^2/pmean[i];
         a = pmean[i]/b;
         parasim[.,i] = b*rndgam(block_size,1,a);
      
      elseif pshape[i] == 3; /* GAUSSIAN PRIOR */
         a = pmean[i];
         b = pstdd[i];
         parasim[.,i] = a + b*rndn(block_size,1);

      elseif pshape[i] == 4; /* INVGAMMA PRIOR */
         a = pmean[i];
         b = pstdd[i];
         parasim[.,i] = sqrt( b*a^2/sumc( (rndn(b,block_size))^2 ) );

      elseif pshape[i] == 5; /* uniform prior */
         a = pmean[i];
         b = pstdd[i];
         parasim[.,i] = a + (b-a)*rndu(block_size,1);
         
      elseif pshape[i] == 6; /* normal truncated at zero */
         a = pmean[i];
         b = pstdd[i];
         parasim[.,i] = a + b* cdfni( rndu(block_size,1)*(1-cdfn(-a/b)) + cdfn(-a/b) ); 
         
      elseif pshape[i] == 0; /* No Prior - Fixed */
         a = pmean[i];
         parasim[.,i] = a*ones(block_size,1);

      endif;

     i = i+1;
   endo; 

   /* Convert theta and alpha1,2 into phi and alpha
   */

   parasim = parasim~thetaalpha_to_phi(parasim,msel)~alp12_to_alp(parasim);

   "Processing Block" block_it;
   
   wr = writer(fhpara,parasim);

   block_it = block_it + 1;

endo;

closeall fhpara;
end;
