/*************************************************************************
**  Simulate the entry model 
**************************************************************************/

/* filename: game_sim.g
** created:  
** Modifications:
**
*/

new;

/** set seed **/
rndseed 1234;

/****************************************************
* Housecleaning and set defaults
****************************************************/

library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

_fcmptol = 1E-10;

#include game_spec.g
#include game_proc.src
#include pathspec.g
   
/* Load model parameters
*/
dgpname   = lmodel $+ dataselstr $+ "par.out";
load path = ^priopath thetaalpha[ndgp_,1] = ^dgpname;

/* Check whether restrictions are satisfied
*/
if msel[1] == 2;
   if thetaalpha[2] ne thetaalpha[4];
      "DGP violates parameter restriction";
      end;
   endif;
endif;

/* Simulate data from entry game:
** entry(Firm1,Firm2) monopoly profits(Firm1,Firm2) duopoly profits(Firm1,Firm2)
*/
yy = gamesim(thetaalpha,msel,nobs);

/* compute reduced form parameters
*/
phi = (thetaalpha_to_phi(thetaalpha',msel))';
alp = alp12_to_alp(thetaalpha');

/* Provide some summary statistics
*/
"Model Specification: " msel;
"Parameter Choice:    " datasel;
"Sample:              " subT;
"Parameters:          "; thetaalpha;
"Slackness:           "; alp;

"";
"No entry:";
yysel = (yy[.,1] .== 0) .and (yy[.,2] .== 0);
yysel = .not yysel;
"Theoretical Fraction:  " phi[1];
if sumc(yysel) < nobs;
      yysub = delif( yy, yysel );
      "Fraction of Markets:     " rows(yysub)/nobs;  
      "Average Monopoly Profits:" meanc(yysub[.,3:4])';
      "Average Duopoly Profits: " meanc(yysub[.,5:6])';
else;
      "Fraction of Markets: 0";
endif;
"";
   
"Firm 1 enters:";
yysel = (yy[.,1] .== 1) .and (yy[.,2] .== 0);
yysel = .not yysel;
"Theoretical Fraction:  " phi[2];
if sumc(yysel) < nobs;
      yysub = delif( yy, yysel );
      "Fraction of Markets:     " rows(yysub)/nobs;  
      "Average Monopoly Profits:" meanc(yysub[.,3:4])';
      "Average Duopoly Profits: " meanc(yysub[.,5:6])';
else;
      "Fraction of Markets: 0";
endif;
"";

   
"Firm 2 enters:";
yysel = (yy[.,1] .== 0) .and (yy[.,2] .== 1);
yysel = .not yysel;
"Theoretical Fraction:  " phi[3];
if sumc(yysel) < nobs;
      yysub = delif( yy, yysel );
      "Fraction of Markets:     " rows(yysub)/nobs;  
      "Average Monopoly Profits:" meanc(yysub[.,3:4])';
      "Average Duopoly Profits: " meanc(yysub[.,5:6])';
else;
      "Fraction of Markets: 0";
endif;
"";
   
"Duopoly:";
yysel = (yy[.,1] .== 1) .and (yy[.,2] .== 1);
yysel = .not yysel;
"Theoretical Fraction:  " phi[4];
if sumc(yysel) < nobs;
      yysub = delif( yy, yysel );
      "Fraction of Markets:     " rows(yysub)/nobs;  
      "Average Monopoly Profits:" meanc(yysub[.,3:4])';
      "Average Duopoly Profits: " meanc(yysub[.,5:6])';
else;
      "Fraction of Markets: 0";
endif;
"";

/********************************************************
** Save simulated data
*/

osimdata         = datapath $+ "\\" 
                   $+ lmodel $+ dataselstr $+ subTstr $+ "data";
create fhsimdata = ^osimdata with DATA, cols(yy), 8;
wr               = writer(fhsimdata,yy);
closeall fhsimdata;   
"Data saved";
