/******************************************************************************
* LOADDATA.G
* reads simulated data into the variable YY
*
* updated:  05/31/2005
******************************************************************************/

if msel[2] == 1;      

   /* load simulated data
   */
   
   lsimdata  = datapath $+ "\\" $+ lmodel $+ dataselstr $+ subTstr $+ "data";
   open fhsimdata = ^lsimdata for read;
   YY = readr(fhsimdata,nobs);
   closeall fhsimdata;   


   /* eliminate observations on unobserved profits
   */
   YY = YY[.,1:2];

   /* Compute blocks of observations with
   ** identical market configuration
   */

   /* No entry */
   yysel = (YY[.,1] .== 0) .and (YY[.,2] .== 0);
   yysel = .not yysel;
   if sumc(yysel < nobs);
      YY00  = delif( YY, yysel );
      n00   = rows(YY00);
   else;
      YY00  = zeros(1,2);
      n00   = 0;
   endif;

   /* Firm 1 */
   yysel = (YY[.,1] .== 1) .and (YY[.,2] .== 0);
   yysel = .not yysel;
   if sumc(yysel < nobs);
      YY10  = delif( YY, yysel );
      n10   = rows(YY10);
   else;
      YY10  = zeros(1,2);
      n10   = 0;
   endif;

   /* Firm 2 */
   yysel = (YY[.,1] .== 0) .and (YY[.,2] .== 1);
   yysel = .not yysel;
   if sumc(yysel < nobs);
      YY01  = delif( YY, yysel );
      n01   = rows(YY01);
   else;
      YY01  = zeros(1,2);
      n01   = 0;
   endif;

   /* Duopoly */
   yysel = (YY[.,1] .== 1) .and (YY[.,2] .== 1);
   yysel = .not yysel;
   if sumc(yysel < nobs);
      YY11  = delif( YY, yysel );
      n11   = rows(YY11);
   else;
      YY11  = zeros(1,2);
      n11   = 0;
   endif;

elseif msel[2] == 2;

   /* set phi-hat = phi0 
   */
   
   /* Load model parameters
   */
   dgpname   = lmodel $+ dataselstr $+ "par.out";
   load path = ^priopath thetaalpha[ndgp_,1] = ^dgpname;

   /* Check whether restrictions are satisfied
   */
   if msel[1] == 2;
      if thetaalpha[2] ne thetaalpha[4];
         "DGP violates parameter restriction";
         end;
      endif;
   endif;

   /* compute reduced form parameters
   */
   phi_hat = (thetaalpha_to_phi(thetaalpha',msel))';

   n00 = phi_hat[1]*nobs;
   n10 = phi_hat[2]*nobs;
   n01 = phi_hat[3]*nobs;
   n11 = phi_hat[4]*nobs;

endif;
